@@ -167,7 +167,7 @@ class CertificateAuthority(object):
     self._ca_key_size = ca_key_size
     self._digest_list = digest_list
     self._default_digest_class = getattr(hashes, self.digest_list[0].upper())
-    self._crt_life_time = datetime.timedelta(crt_life_time, 0)
+    self._crt_life_time = datetime.timedelta(days=crt_life_time)
     self._crl_base_url = crl_base_url
     self._ca_subject = x509.Name([
       x509.NameAttribute(
@@ -180,14 +180,14 @@ class CertificateAuthority(object):
     if ca_life_period < 3:
       raise ValueError("ca_life_period must be >= 3 to allow CA rollout")
     self._crl_life_time = datetime.timedelta(
-      crt_life_time * crl_renew_period,
-      0,
+      days=crt_life_time * crl_renew_period,
     )
     self._crl_renew_time = datetime.timedelta(
-      crt_life_time * crl_renew_period * .5,
-      0,
+      days=crt_life_time * crl_renew_period * .5,
+    )
+    self._ca_life_time = datetime.timedelta(
+      days=crt_life_time * ca_life_period,
     )
-    self._ca_life_time = datetime.timedelta(crt_life_time * ca_life_period, 0)
     self._loadCAKeyPairList()
     self._renewCAIfNeeded()
 
@@ -450,7 +450,7 @@ class CertificateAuthority(object):
       for policy in certificate_policies.value:
         if policy.policy_identifier.dotted_string.startswith(
           utils.CAUCASE_LEGACY_OID_TOP
-        ):
+        ): # pragma: no cover
           # Always migrate CAUCASE_LEGACY_OID_TOP to CAUCASE_OID_TOP
           # by copying current policy and replacing its prefix to the new
           # OID prefix
@@ -508,7 +508,9 @@ class CertificateAuthority(object):
         self._ca_key_pairs_list[-1]['crt'].not_valid_after -
         datetime.datetime.utcnow()
       ).total_seconds() / self._crt_life_time.total_seconds() <= 2
-    ) and self._ca_renewal_lock.acquire(False):
+      # pylint: disable=consider-using-with
+      ) and self._ca_renewal_lock.acquire(False):
+      # pylint: enable=consider-using-with
       try:
         # No CA certificate at all or less than 2 certificate validity periods
         # left with latest CA certificate. Prepare the next one so it starts
