@@ -84,7 +84,7 @@ class RetryingCaucaseClient(CaucaseClient):
         connection.close() # Resets HTTPConnection state machine.
         # Note: repr(str(exception)) is nicer than repr(exception), without
         # letting non-printable characters through.
-        next_try = datetime.datetime.utcnow() + datetime.timedelta(0, 10)
+        next_try = datetime.datetime.utcnow() + datetime.timedelta(seconds=10)
         print(
           u'Got a network error, retrying at %s, %s: %r' % (
             next_try.strftime(u'%Y-%m-%d %H:%M:%S +0000'),
@@ -654,8 +654,7 @@ def main(argv=None, stdout=sys.stdout, stderr=sys.stderr):
       updated, error = client.renewCRT(
         crt_key_list=args.renew_crt,
         renewal_deadline=datetime.datetime.utcnow() + datetime.timedelta(
-          args.threshold,
-          0,
+          days=args.threshold,
         ),
         key_len=args.key_len,
         ca_certificate_list=ca_list,
@@ -867,10 +866,10 @@ def updater(argv=None, until=utils.until):
       MODE_SERVICE: cas_url,
       MODE_USER: args.ca_url + '/cau',
     }[args.mode]
-    threshold = datetime.timedelta(args.threshold, 0)
-    crl_threshold = datetime.timedelta(args.crl_threshold, 0)
-    max_sleep = datetime.timedelta(args.max_sleep, 0)
-    min_sleep = datetime.timedelta(0, 60)
+    threshold = datetime.timedelta(days=args.threshold)
+    crl_threshold = datetime.timedelta(days=args.crl_threshold)
+    max_sleep = datetime.timedelta(days=args.max_sleep)
+    min_sleep = datetime.timedelta(seconds=60)
     updated = RetryingCaucaseClient.updateCAFile(
       cas_url,
       args.cas_ca,
@@ -897,7 +896,7 @@ def updater(argv=None, until=utils.until):
           # through.
           client.getCertificateSigningRequest(csr_id)
           # Still here ? Ok, wait a bit and try again.
-          until(datetime.datetime.utcnow() + datetime.timedelta(0, 60))
+          until(datetime.datetime.utcnow() + datetime.timedelta(seconds=60))
         else:
           with open(args.crt, 'ab') as crt_file:
             crt_file.write(crt_pem)
