@@ -320,7 +320,7 @@ def getSSLContext(
     )),
   )
   http_cas_certificate_list = http_cas.getCACertificateList()
-  threshold_delta = datetime.timedelta(threshold, 0)
+  threshold_delta = datetime.timedelta(days=threshold)
   exists = os.path.exists(server_key_path)
   if exists:
     try:
@@ -812,7 +812,7 @@ def main(
       server_side=True,
     )
   if args.backup_directory:
-    backup_period = datetime.timedelta(args.backup_period, 0)
+    backup_period = datetime.timedelta(days=args.backup_period)
     try:
       next_backup = max(
         utils.timestamp2datetime(os.stat(x).st_ctime)
@@ -881,7 +881,7 @@ def main(
             next_backup = now + backup_period
           else:
             os.unlink(tmp_backup_path)
-            next_backup = now + datetime.timedelta(0, 3600)
+            next_backup = now + datetime.timedelta(seconds=3600)
         next_deadline = min(
           next_ssl_update,
           next_backup,
@@ -1062,7 +1062,7 @@ def manage(argv=None, stdout=sys.stdout):
       db_path,
       table_prefix='cas',
     )
-    for identifier, ca_pair in import_ca_dict.items():
+    for identifier, ca_pair in list(import_ca_dict.items()):
       found_from = ', '.join(ca_pair['from'])
       crt = ca_pair['crt']
       if crt is None:
